@@ -121,6 +121,12 @@ def run_remote_command_logic(args, project_name, project_version):
     tf_setup_name_sufix = "{}-{}".format(args.setup_name_sufix, tf_github_sha)
     s3_bucket_name = args.s3_bucket_name
     local_module_files = args.module_path
+    for pos, module_file in enumerate(local_module_files):
+        if " " in module_file:
+            logging.info(
+                "Detected multiple files in single module path {}".format(module_file)
+            )
+            local_module_files[pos] = module_file.split(" ")
     dbdir_folder = args.dbdir_folder
     private_key = args.private_key
     grafana_profile_dashboard = args.grafana_profile_dashboard
@@ -362,7 +368,12 @@ def run_remote_command_logic(args, project_name, project_version):
                             shard_count,
                         ) = get_setup_type_and_primaries_count(setup_settings)
                         if args.allowed_setups != "":
-                            allowed_setups = args.allowed_setups.split()
+                            allowed_setups = args.allowed_setups.split(",")
+                            logging.info(
+                                "Checking if setup named {} of topology type {}. Total primaries: {} is in the allowed list of setups {}".format(
+                                    setup_name, setup_type, shard_count, allowed_setups
+                                )
+                            )
                             if setup_name not in allowed_setups:
                                 logging.warning(
                                     "SKIPPING setup named {} of topology type {}.".format(
@@ -374,7 +385,6 @@ def run_remote_command_logic(args, project_name, project_version):
                             s3_bucket_name, test_name, tf_github_org, tf_github_repo
                         )
                         if setup_type in args.allowed_envs:
-
                             logging.info(
                                 "Starting setup named {} of topology type {}. Total primaries: {}".format(
                                     setup_name, setup_type, shard_count
@@ -417,7 +427,6 @@ def run_remote_command_logic(args, project_name, project_version):
                                 # after we've created the env, even on error we should always teardown
                                 # in case of some unexpected error we fail the test
                                 try:
-
                                     (
                                         _,
                                         _,
